@@ -1,5 +1,5 @@
 /*
- * AutomatableButton.h - class AutomatableButton, the base for all buttons
+ * AutomatableButton.h - class automatableButton, the base for all buttons
  *
  * Copyright (c) 2006-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
@@ -22,26 +22,25 @@
  *
  */
 
-#ifndef LMMS_GUI_AUTOMATABLE_BUTTON_H
-#define LMMS_GUI_AUTOMATABLE_BUTTON_H
+
+#ifndef AUTOMATABLE_BUTTON_H
+#define AUTOMATABLE_BUTTON_H
 
 #include <QPushButton>
 
 #include "AutomatableModelView.h"
 
-namespace lmms::gui
-{
 
-class AutomatableButtonGroup;
+class automatableButtonGroup;
 
 
-class LMMS_EXPORT AutomatableButton : public QPushButton, public BoolModelView
+class EXPORT AutomatableButton : public QPushButton, public BoolModelView
 {
 	Q_OBJECT
 public:
 	AutomatableButton( QWidget * _parent, const QString & _name
-			= QString() );
-	~AutomatableButton() override;
+			= QString::null );
+	virtual ~AutomatableButton();
 
 	inline void setCheckable( bool _on )
 	{
@@ -49,7 +48,7 @@ public:
 		model()->setJournalling( _on );
 	}
 
-	void modelChanged() override;
+	virtual void modelChanged();
 
 
 public slots:
@@ -63,16 +62,16 @@ public slots:
 
 
 protected:
-	void contextMenuEvent( QContextMenuEvent * _me ) override;
-	void mousePressEvent( QMouseEvent * _me ) override;
-	void mouseReleaseEvent( QMouseEvent * _me ) override;
+	virtual void contextMenuEvent( QContextMenuEvent * _me );
+	virtual void mousePressEvent( QMouseEvent * _me );
+	virtual void mouseReleaseEvent( QMouseEvent * _me );
 
 
 private:
-	AutomatableButtonGroup * m_group;
+	automatableButtonGroup * m_group;
 
 
-	friend class AutomatableButtonGroup;
+	friend class automatableButtonGroup;
 
 	using QPushButton::setChecked;
 	using QPushButton::isChecked;
@@ -80,20 +79,20 @@ private:
 
 
 
-class LMMS_EXPORT AutomatableButtonGroup : public QWidget, public IntModelView
+class EXPORT automatableButtonGroup : public QWidget, public IntModelView
 {
 	Q_OBJECT
 public:
-	AutomatableButtonGroup( QWidget * _parent, const QString & _name
-			= QString() );
-	~AutomatableButtonGroup() override;
+	automatableButtonGroup( QWidget * _parent, const QString & _name
+			= QString::null );
+	virtual ~automatableButtonGroup();
 
 	void addButton( AutomatableButton * _btn );
 	void removeButton( AutomatableButton * _btn );
 
 	void activateButton( AutomatableButton * _btn );
 
-	void modelChanged() override;
+	virtual void modelChanged();
 
 
 private slots:
@@ -106,6 +105,5 @@ private:
 } ;
 
 
-} // namespace lmms::gui
 
-#endif // LMMS_GUI_AUTOMATABLE_BUTTON_H
+#endif
